@@ -10,6 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
 import re
 
 import mock
@@ -20,6 +21,7 @@ from nectarallocationclient.tests.unit import fakes
 from nectarallocationclient.tests.unit import utils
 from nectarallocationclient.v1 import allocations
 from nectarallocationclient.v1 import client
+from nectarallocationclient.v1 import facilities
 from nectarallocationclient.v1 import quotas
 from nectarallocationclient.v1 import resources
 from nectarallocationclient.v1 import service_types
@@ -89,7 +91,19 @@ generic_allocation = {
             "resource": "container-infra.clusters",
             "quota": 1,
             "id": 8
-        }
+        },
+        {
+            "zone": "nectar",
+            "resource": "database.ram",
+            "quota": 8,
+            "id": 9
+        },
+        {
+            "zone": "nectar",
+            "resource": "rating.budget",
+            "quota": 56,
+            "id": 10
+        },
     ],
     "status": "A",
     "submit_date": "2018-07-03",
@@ -136,6 +150,7 @@ class FakeClient(fakes.FakeClient, client.Client):
         self.service_types = service_types.ServiceTypeManager(self.http_client)
         self.zones = zones.ZoneManager(self.http_client)
         self.sites = sites.SiteManager(self.http_client)
+        self.facilities = facilities.FacilityManager(self.http_client)
 
 
 class FakeSessionClient(base_client.SessionClient):
@@ -326,6 +341,19 @@ class FakeSessionClient(base_client.SessionClient):
     def get_allocations_123(self, **kw):
         return (200, {}, generic_allocation)
 
+    def get_allocations_124(self, **kw):
+        allocation_124 = copy.deepcopy(generic_allocation)
+        allocation_124['id'] = 124
+        allocation_124['quotas'][1]['quota'] = 0   # RAM
+        return (200, {}, allocation_124)
+
+    def get_allocations_125(self, **kw):
+        allocation_125 = copy.deepcopy(generic_allocation)
+        allocation_125['id'] = 125
+        allocation_125['quotas'][0]['quota'] = -1  # VCPUs
+        allocation_125['quotas'][1]['quota'] = 0   # RAM
+        return (200, {}, allocation_125)
+
     def patch_allocations_123(self, data, **kw):
         return (202, {'notes': 'test'},
                 {"id": 123,
@@ -442,6 +470,26 @@ class FakeSessionClient(base_client.SessionClient):
                 "enabled": False
             })
 
+    def get_ncris_facilities(self, **kw):
+        facilities = [
+            {
+                "name": "Applied Magic Facility",
+                "short_name": "AMF",
+            },
+            {
+                "name": "Pure Magic Facility",
+                "short_name": "PMF",
+            }
+        ]
+        return (200, {}, facilities)
+
+    def get_ncris_facilities_AMF(self, **kw):
+        return (200, {},
+            {
+                "name": "Applied Magic Facility",
+                "short_name": "AMF",
+            })
+
     def get_zones(self, **kw):
         zones = [
             {
